@@ -7,7 +7,7 @@ use Mojo::ByteStream qw( b );
 use Mojo::Base 'Mojolicious::Plugin';
 
 # ABSTRACT: Self authentication for PlugAuth
-our $VERSION = '0.32'; # VERSION
+our $VERSION = '0.33'; # VERSION
 
 
 sub register {
@@ -24,7 +24,7 @@ sub authenticate
   # Everyone needs to send an authorization header
   my $auth = $c->req->headers->authorization or do {
     $c->res->headers->www_authenticate(qq[Basic realm="$realm"]);
-    $c->render_text("auth required", layout => "", status => 401);
+    $c->render(text => "auth required", layout => "", status => 401);
     return;
   };
   
@@ -78,7 +78,7 @@ Clustericious::Plugin::SelfPlugAuth - Self authentication for PlugAuth
 
 =head1 VERSION
 
-version 0.32
+version 0.33
 
 =head1 DESCRIPTION
 
