@@ -1,7 +1,7 @@
 package PlugAuth::Plugin::Test;
 
 # ABSTRACT: Test Plugin server
-our $VERSION = '0.32'; # VERSION
+our $VERSION = '0.33'; # VERSION
 
 use strict;
 use warnings;
@@ -35,7 +35,7 @@ sub init
     $self->real_auth->refresh;
     $self->real_authz->refresh;
 
-    shift->render_text('ok');
+    shift->render(text => 'ok');
   });
   $self->app->routes->route('/test/setup/basic')->post(sub {
     my $auth = $self->real_auth;
@@ -49,7 +49,7 @@ sub init
     $authz->grant('admin', 'accounts', '/');
     $authz->grant('primus', 'accounts', '/');
     
-    shift->render_text('ok');
+    shift->render(text => 'ok');
   });
 }
 
@@ -129,7 +129,7 @@ PlugAuth::Plugin::Test - Test Plugin server
 
 =head1 VERSION
 
-version 0.32
+version 0.33
 
 =head1 AUTHOR
 
